@@ -1,7 +1,7 @@
 /* Copyright 2003 Roger Dingledine. */
 /* See LICENSE for licensing information */
-/* $Id: tortls.c,v 1.82 2004/12/07 07:47:57 nickm Exp $ */
-const char tortls_c_id[] = "$Id: tortls.c,v 1.82 2004/12/07 07:47:57 nickm Exp $";
+/* $Id: tortls.c,v 1.82.2.3 2005/04/23 20:36:19 nickm Exp $ */
+const char tortls_c_id[] = "$Id: tortls.c,v 1.82.2.3 2005/04/23 20:36:19 nickm Exp $";
 
 /**
  * \file tortls.c
@@ -500,12 +500,17 @@ tor_tls_handshake(tor_tls *tls)
   tor_assert(tls);
   tor_assert(tls->ssl);
   tor_assert(tls->state == TOR_TLS_ST_HANDSHAKE);
+  check_no_tls_errors();
   if (tls->isServer) {
     r = SSL_accept(tls->ssl);
   } else {
     r = SSL_connect(tls->ssl);
   }
   r = tor_tls_get_error(tls,r,0, "handshaking", LOG_INFO);
+  if (ERR_peek_error() != 0) {
+    tls_log_errors(LOG_WARN, "handshaking");
+    return TOR_TLS_ERROR;
+  }
   if (r == TOR_TLS_DONE) {
     tls->state = TOR_TLS_ST_OPEN;
   }
@@ -803,14 +808,12 @@ unsigned long tor_tls_get_n_bytes_written(tor_tls *tls)
 
 /** Implement assert_no_tls_errors: If there are any pending OpenSSL
  * errors, log an error message and assert(0). */
-void _assert_no_tls_errors(const char *fname, int line)
+void _check_no_tls_errors(const char *fname, int line)
 {
   if (ERR_peek_error() == 0)
     return;
-  log_fn(LOG_ERR, "Unhandled OpenSSL errors found at %s:%d: ",
+  log_fn(LOG_WARN, "Unhandled OpenSSL errors found at %s:%d: ",
          fname, line);
-  tls_log_errors(LOG_ERR, NULL);
-
-  tor_assert(0);
+  tls_log_errors(LOG_WARN, NULL);
 }
 
