@@ -1,10 +1,10 @@
 /* Copyright 2003 Roger Dingledine */
 /* See LICENSE for licensing information */
-/* $Id: tortls.h,v 1.22.2.1 2004/12/22 02:57:32 nickm Exp $ */
+/* $Id: tortls.h,v 1.22.2.2 2005/04/23 14:32:25 nickm Exp $ */
 
 #ifndef _TORTLS_H
 #define _TORTLS_H
-#define TORTLS_H_ID "$Id: tortls.h,v 1.22.2.1 2004/12/22 02:57:32 nickm Exp $"
+#define TORTLS_H_ID "$Id: tortls.h,v 1.22.2.2 2005/04/23 14:32:25 nickm Exp $"
 
 /**
  * \file tortls.h
@@ -43,9 +43,9 @@ unsigned long tor_tls_get_n_bytes_written(tor_tls *tls);
 
 /* Log and abort if there are unhandled TLS errors in OpenSSL's error stack.
  */
-#define assert_no_tls_errors() _assert_no_tls_errors(_SHORT_FILE_,__LINE__)
+#define check_no_tls_errors() _check_no_tls_errors(_SHORT_FILE_,__LINE__)
 
-void _assert_no_tls_errors(const char *fname, int line);
+void _check_no_tls_errors(const char *fname, int line);
 
 #endif
 
