@@ -2,8 +2,8 @@
  * Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: buffers.c,v 1.122.2.3 2005/01/03 23:20:28 arma Exp $ */
-const char buffers_c_id[] = "$Id: buffers.c,v 1.122.2.3 2005/01/03 23:20:28 arma Exp $";
+/* $Id: buffers.c,v 1.122.2.4 2005/04/23 14:32:25 nickm Exp $ */
+const char buffers_c_id[] = "$Id: buffers.c,v 1.122.2.4 2005/04/23 14:32:25 nickm Exp $";
 
 /**
  * \file buffers.c
@@ -226,7 +226,7 @@ int read_to_buf_tls(tor_tls *tls, size_t at_most, buf_t *buf) {
          (int)buf_datalen(buf), (int)tor_tls_get_pending_bytes(tls),
          (int)at_most);
 
-  assert_no_tls_errors();
+  check_no_tls_errors();
   r = tor_tls_read(tls, buf->mem+buf->datalen, at_most);
   if (r<0)
     return r;
